library(zoo)


##### Analysis of Heme-to-Heme electron transfer

hda_i_w378<- c()
tempo <-data.frame(read.table(file='PMalgn_H2H_i_300_w378.dat',header=FALSE))
hda_i_w378<- cbind(hda_i_w378,tempo[,3]) 
hda_f_w378<- c()
tempo <-data.frame(read.table(file='PMalgn_H2H_f_300_w378.dat',header=FALSE))
hda_f_w378<- cbind(hda_f_w378,tempo[,3]) 


hda_i_f348<- c()
tempo <-data.frame(read.table(file='PMalgn_H2H_i_300_f348.dat',header=FALSE))
hda_i_f348<- cbind(hda_i_f348,tempo[,3]) 
hda_f_f348<- c()
tempo <-data.frame(read.table(file='PMalgn_H2H_f_300_f348.dat',header=FALSE))
hda_f_f348<- cbind(hda_f_f348,tempo[,3]) 


hda_f_all<- c()
hda_f_all<- append(hda_f_w378,hda_f_f348)
hdasq_f_all<- c()
hdasq_f_all<- append(hda_f_w378^2,hda_f_f348^2)
hda_i_all<- c()
hda_i_all<- append(hda_i_w378,hda_i_f348)
hdasq_i_all<- c()
hdasq_i_all<- append(hda_i_w378^2,hda_i_f348^2)


# Data provided in Table 1

   H0 = 0.177829  # Contact coupling in eV
   print(c(mean(hda_i_w378),var(hda_i_w378)))
   print(c(mean(hda_i_f348),var(hda_i_f348)))
   print(c(mean(hda_i_all),   var(hda_i_all) , mean(hda_i_all)*H0 , mean(hdasq_i_all) , 
           mean(hda_i_all)*mean(hda_i_all)/ mean(hdasq_i_all)  ))

  
   print(c(mean(hda_f_w378),var(hda_f_w378)))
   print(c(mean(hda_f_f348),var(hda_f_f348)))
   print(c(mean(hda_f_all),   var(hda_f_all) , mean(hda_f_all)*H0 , mean(hdasq_f_all) , 
           mean(hda_f_all)*mean(hda_f_all)/ mean(hdasq_f_all)  ))
   
   
   # Data provided in Table 1
binsize=0.000001
hist_i_f348<-hist(hda_i_f348,breaks=seq(0.0,0.001,binsize),plot=FALSE)
hist_i_w378<-hist(hda_i_w378,breaks=seq(0.0,0.001,binsize),plot=FALSE)

hist_f_f348<-hist(hda_f_f348,breaks=seq(0.0,0.001,binsize),plot=FALSE)
hist_f_w378<-hist(hda_f_w378,breaks=seq(0.0,0.001,binsize),plot=FALSE)



tiff(filename = "Figure6right.tiff",
     width = 1500, height = 1200, units = "px", pointsize = 30,
     bg = "white",  res = NA,
     type = c("cairo", "Xlib", "quartz") )

ntot=15000
plot(hist_f_w378$mids,hist_f_w378$counts/ntot,lwd=5,type='l',col="green",
     lty=1,xlim=c(0.0,0.0001),ylim=c(0,0.05), axes=FALSE,xlab="",ylab="")
lines(hist_i_w378$mids,hist_i_w378$counts/ntot,lwd=5,type='l',col="green",
      lty=3,xlim=c(0.0,0.0001),ylim=c(0,0.05))
lines(hist_f_f348$mids,hist_f_f348$counts/ntot,lwd=5,type='l',col="red",
      lty=1,xlim=c(0.0,0.0001),ylim=c(0,0.05))
lines(hist_i_f348$mids,hist_i_f348$counts/ntot,lwd=5,type='l',col="red",
      lty=3,xlim=c(0.0,0.0001),ylim=c(0,0.05))

axis(1,at=seq(0,0.0001,0.00001),pos=0,cex.axis=1.75 ,lwd=5)
axis(2,at=seq(0,0.05,0.01),pos=0,cex.axis=1.5,lwd=5,las=1)

title(cex.main=1.75,xlab="decay factor",
      cex.lab=1.75,line=2)
title(cex.main=1.75,
      ylab="probability density (norm.)",cex.lab=1.75,line=3)
dev.off()


##### Analysis of Heme-to-O2 electron transfer

hda_i_dir<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_i_all_dir.dat',header=FALSE))
hda_i_dir<- cbind(hda_i_dir,tempo[,3]) 
hda_f_dir<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_f_all_dir.dat',header=FALSE))
hda_f_dir<- cbind(hda_f_dir,tempo[,3]) 

hda_i_h313<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_i_all_h313.dat',header=FALSE))
hda_i_h313<- cbind(hda_i_h313,tempo[,3]) 
hda_f_h313<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_f_all_h313.dat',header=FALSE))
hda_f_h313<- cbind(hda_f_h313,tempo[,3]) 

hda_i_h317<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_i_all_h317.dat',header=FALSE))
hda_i_h317<- cbind(hda_i_h317,tempo[,3]) 
hda_f_h317<- c()
tempo <-data.frame(read.table(file='PMalgn_H2O2_f_all_h317.dat',header=FALSE))
hda_f_h317<- cbind(hda_f_h317,tempo[,3]) 


binsize=0.001
hist_i_dir<-hist(hda_i_dir,breaks=seq(0.0,0.8,binsize),plot=FALSE)
hist_i_h313<-hist(hda_i_h313,breaks=seq(0.0,0.8,binsize),plot=FALSE)
hist_i_h317<-hist(hda_i_h317,breaks=seq(0.0,0.8,binsize),plot=FALSE)

hist_f_dir<-hist(hda_f_dir,breaks=seq(0.0,0.8,binsize),plot=FALSE)
hist_f_h313<-hist(hda_f_h313,breaks=seq(0.0,0.8,binsize),plot=FALSE)
hist_f_h317<-hist(hda_f_h317,breaks=seq(0.0,0.8,binsize),plot=FALSE)

tiff(filename = "Figure8a.tiff",
     width = 1500, height = 1200, units = "px", pointsize = 30,
     bg = "white",  res = NA,
     type = c("cairo", "Xlib", "quartz") )

ntot=25000
plot(hist_f_h317$mids,hist_f_h317$counts/ntot,lwd=5,type='l',col="seagreen",
     lty=1,xlim=c(0.0,0.15),ylim=c(0,0.2), axes=FALSE,xlab="",ylab="")
lines(hist_i_h317$mids,hist_i_h317$counts/ntot,lwd=5,type='l',col="seagreen",
      lty=3,xlim=c(0.0,0.15),ylim=c(0,0.2))
lines(hist_f_dir$mids,hist_f_dir$counts/ntot,lwd=5,type='l',col="red",
      lty=1,xlim=c(0.0,0.15),ylim=c(0,0.2))
lines(hist_i_dir$mids,hist_i_dir$counts/ntot,lwd=5,type='l',col="red",
      lty=3,xlim=c(0.0,0.15),ylim=c(0,0.2))

axis(1,at=seq(0,0.2,0.05),pos=0,cex.axis=1.75 ,lwd=5)
axis(2,at=seq(0,0.2,0.05),pos=0,cex.axis=1.5,lwd=5,las=1)

title(cex.main=1.75,xlab="decay factor",
     cex.lab=1.75,line=2)
title(cex.main=1.75,
      ylab="probability density (norm.)",cex.lab=1.75,line=3)
dev.off()

