
# Load packages
library(coda)
library(zoo)
#Conversion factors
ev2ha=0.0367502
kcalmol2ua=0.00159362
kcalmol2ev=0.0433634
j2eV=6.24181e18
bohr=5.2917721092*1E-11

#Setting temperature
temp=298.

# Constants
kb=1.3806488e-23
hbar=1.054571726E-34
kbTeV=kb*temp*j2eV
kbTha=kbTeV*ev2ha



# Read Energy gap IMPORTANT: the files give Ei - Ef in eV
	### Initialize vectors
  
  gap_1l <- c() # gap run 1, 300ns, redox state 1
  gap_1s<- c() # gap run  2 and 3, 100ns each, redox state 1
  gap_1 <-c() # gap redox state 1, collect all data point
  gap_2l <- c()  # gap run 1, 300ns, redox state 2
  gap_2s<- c()# gap run  2 and 3, 100ns each, redox state 2
  gap_1 <-c() # gap redox state 2, collect all data point 
  
  sysrep <-"withO2"
  temp <- data.frame(read.table(file=paste0(sysrep,'/300ns/Ei-300'),header=FALSE))
  gap_1l<- cbind(gap_1l,-temp[,2]) 
  gap_1s<- cbind(gap_1s,-temp[1:40000,2])
  gap_1s<- cbind(gap_1s,-temp[50001:90000,2]) 
  gap_1s<- cbind(gap_1s,-temp[100001:140000,2])
  temp <- data.frame(read.table(file=paste0(sysrep,'/100ns/run1/Ei-100'),header=FALSE))
  gap_1s<- cbind(gap_1s,-temp[10001:50000,2])
  temp <- data.frame(read.table(file=paste0(sysrep,'/100ns/run2/Ei-100'),header=FALSE))
  gap_1s<- cbind(gap_1s,-temp[10001:50000,2])
  gap_1 < c()
  gap_1 <-append(gap_1l,gap_1s[,4])
  gap_1 <-append(gap_1,gap_1s[,5])
  
  temp <- data.frame(read.table(file='withO2/300ns/Ef-300',header=FALSE))
  gap_2l<- cbind(gap_2l,-temp[,2]) 
  gap_2s<- cbind(gap_2s,-temp[1:40000,2]) 
  gap_2s<- cbind(gap_2s,-temp[50001:90000,2]) 
  gap_2s<- cbind(gap_2s,-temp[100001:140000,2])
  temp <- data.frame(read.table(file='withO2/100ns/run1/Ef-100',header=FALSE))
  gap_2s<- cbind(gap_2s,-temp[10001:50000,2])
  temp <- data.frame(read.table(file='withO2/100ns/run2/Ef-100',header=FALSE))
  gap_2s<- cbind(gap_2s,-temp[10001:50000,2])
  gap_2 <- c()
  gap_2 <-append(gap_2l,gap_2s[,4])
  gap_2 <-append(gap_2,gap_2s[,5])


######################################################################################################

#  Marcus Theory parameters calculations

  first=1 
  endl=140000
  deltag <- c()
  lamSt <- c()
  lamV1 <- c()
  lamV2 <- c()
  u_dglSt <- c()
  u_lamV1 <- c()
  u_lamV2 <- c()
  u_dgact <- c()

 
    deltag<-rbind(deltag,0.5*(mean(gap_1l[]) + mean(gap_2l[ ])))
    deltag<-rbind(deltag,0.5*(mean(gap_1s[ ,1]) + mean(gap_2s[ ,1])))
    deltag<-rbind(deltag,0.5*(mean(gap_1s[ ,2]) + mean(gap_2s[ ,2])))
    deltag<-rbind(deltag,0.5*(mean(gap_1s[ ,3]) + mean(gap_2s[ ,3])))
    deltag<-rbind(deltag,0.5*(mean(gap_1s[ ,4]) + mean(gap_2s[ ,4])))
    deltag<-rbind(deltag,0.5*(mean(gap_1s[ ,5]) + mean(gap_2s[ ,5])))
    deltag<-rbind(deltag,0.5*(mean(gap_1) + mean(gap_2)))
    deltagb<-mean(deltag[2:6])
    
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1l[ ])/effectiveSize(gap_1l[ ]) 
                                   + var(gap_2l[ ])/effectiveSize(gap_2l[ ]))) )
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1s[ ,1])/effectiveSize(gap_1s[,1 ]) 
                                   + var(gap_2s[ ,1])/effectiveSize(gap_2s[,1 ]))) )
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1s[ ,2])/effectiveSize(gap_1s[,2 ]) 
                                   + var(gap_2s[ ,2])/effectiveSize(gap_2s[,2 ]))) )
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1s[ ,3])/effectiveSize(gap_1s[,3 ]) 
                                   + var(gap_2s[ ,3])/effectiveSize(gap_2s[,3 ]))) )
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1s[ ,4])/effectiveSize(gap_1s[,4 ]) 
                                   + var(gap_2s[ ,4])/effectiveSize(gap_2s[,4 ]))) )
    u_dglSt <- rbind(u_dglSt,sqrt(0.25*(var(gap_1s[ ,5])/effectiveSize(gap_1s[,5 ]) 
                                   + var(gap_2s[ ,5])/effectiveSize(gap_2s[,5 ]))) )
    u_dglStb<-sd(deltag[2:6])/sqrt(5)
    
    
    
    lamSt<-rbind(lamSt,0.5*(mean(gap_1l[ ])- mean(gap_2l[ ])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1s[ ,1]) - mean(gap_2s[ ,1])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1s[ ,2]) - mean(gap_2s[ ,2])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1s[ ,3]) - mean(gap_2s[ ,3])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1s[ ,4]) - mean(gap_2s[ ,4])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1s[ ,5]) - mean(gap_2s[ ,5])))
    lamSt<-rbind(lamSt,0.5*(mean(gap_1[ ])- mean(gap_2[ ])))
    lamStb<-mean(lamSt[2:6])
    
    u_lamSt<-u_dglSt
    u_lamStb<-sd(lamSt[2:6])/sqrt(5)
    
    lamV1<-rbind(lamV1,var(gap_1l[ ])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1s[ ,1])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1s[ ,2])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1s[ ,3])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1s[ ,4])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1s[ ,5])/(2*kbTeV))
    lamV1<-rbind(lamV1,var(gap_1[ ])/(2*kbTeV))
    lamV1b<-mean(lamV1[2:6])
    
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1l[ ])^2/(effectiveSize(gap_1l[ ])*kbTeV^2)))
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1s[,1])^2/(effectiveSize(gap_1s[,1 ])*kbTeV^2)))
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1s[,2])^2/(effectiveSize(gap_1s[,2])*kbTeV^2)))
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1s[,3])^2/(effectiveSize(gap_1s[,3])*kbTeV^2)))
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1s[,4])^2/(effectiveSize(gap_1s[,4])*kbTeV^2)))
    u_lamV1<-rbind(u_lamV1,sqrt(var(gap_1s[,5])^2/(effectiveSize(gap_1s[,5])*kbTeV^2)))
    u_lamV1b<-sd(lamV1[2:6])/sqrt(5)
    
    
    lamV2<-rbind(lamV2,var(gap_2l[ ])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2s[ ,1])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2s[ ,2])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2s[ ,3])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2s[ ,4])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2s[ ,5])/(2*kbTeV))
    lamV2<-rbind(lamV2,var(gap_2[ ])/(2*kbTeV))
    lamV2b<-mean(lamV2[2:6])
    
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2l[ ])^2/(effectiveSize(gap_2l[ ])*kbTeV^2)))
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2s[,1])^2/(effectiveSize(gap_2s[,1 ])*kbTeV^2)))
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2s[,2])^2/(effectiveSize(gap_2s[,2])*kbTeV^2)))
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2s[,3])^2/(effectiveSize(gap_2s[,3])*kbTeV^2)))
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2s[,4])^2/(effectiveSize(gap_2s[,4])*kbTeV^2)))
    u_lamV2<-rbind(u_lamV2,sqrt(var(gap_2s[,5])^2/(effectiveSize(gap_2s[,5])*kbTeV^2)))
    u_lamV2b<-sd(lamV2[2:6])/sqrt(5)

######################################################################################################

# Plots of various quantities

# PLot energy gaps with respect to time
  
tiff(filename = "Figure3a.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )
    l300ns=140000
    l100ns=40000
    xmin=1
    xmax=500
    nrol=200
    xtime <- seq(20,300,length.out = l300ns)
    ymin=floor(min(c(min(gap_1l[xmin:xmax]),min(gap_2l[xmin:xmax]))))
    ymax=ceiling(max(c(max(gap_1l[xmin:xmax]),max(gap_2l[xmin:xmax]))))
    par(mar=c(5.5,5.5,2,2))
    plot(rollmean(xtime[1:l100ns],nrol),rollmean(gap_2s[1:l100ns,1],nrol),type="l",lwd=2,col="seagreen",axes=FALSE,xlab="",ylab="",ylim=c(-2,2),xlim=c(xmin,xmax))
    for (i in seq(1,4)) {
      lag=i*100
      couleur=paste0("seagreen",i)
      lines(lag+rollmean(xtime[1:l100ns],nrol),rollmean(gap_2s[1:l100ns,i+1],nrol),type="l",lwd=2,col=couleur)
    }
    lines(rollmean(xtime[1:l100ns],nrol),rollmean(gap_1s[1:l100ns,1],nrol),type="l",lwd=2,col="red")
    for (i in seq(1,4)) {
      lag=i*100
      couleur=paste0("red",i)
      lines(lag+rollmean(xtime[1:l100ns],nrol),rollmean(gap_1s[1:l100ns,i+1],nrol),type="l",lwd=2,col=couleur)
    }
    
lines(xy.coords(c(0,500),c(-1.35,-1.35)),lwd=2,lty=2)
lines(xy.coords(c(0,500),c(0.6,0.6)),lwd=2,lty=2)
lines(xy.coords(c(0,500),c(1.0,1.0)),lwd=2,lty=2)

axis(1,at=seq(0,500,50),pos=-2,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(-2,ymax+1,1),pos=1,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="Time (ns)", 
      ylab="Energy gap (eV)",cex.lab=1.75,line=1.5)

dev.off()




tiff(filename = "Figure4a.tiff",
     width = 1500, height = 1200, units = "px", pointsize = 30,
     bg = "white",  res = NA,
     type = c("cairo", "Xlib", "quartz") )


par(mar = c(5, 6, 4, 5) + 0.3)
tabbedMeans <- cbind(c(deltag[2:6],deltagb,deltag[1]),c(lamSt[2:6],lamStb,lamSt[1]),c(lamV1[2:6],lamV1b,lamV1[1]),c(lamV2[2:6],lamV2b,lamV2[1]))
tabbedSE <- cbind(c(u_dglSt[2:6],u_dglStb,u_dglSt[1]),c(u_lamSt[2:6],u_lamStb,u_lamSt[1]),c(u_lamV1[2:6],u_lamV1b,u_lamV1[1]),c(u_lamV2[2:6],u_lamV2b,u_lamV2[1]))

barCenters <- barplot(height = tabbedMeans,beside=TRUE,axes=FALSE,ylim=c(-0.5,5.0),
                      col=c(grey(level=0.5),grey(level=0.6),grey(level=0.7),grey(level=0.8),grey(level=0.9),"seagreen","red2"))

text(x = c(6,14,22.5,30.5), y = c(0.25,-0.25,-0.25,-0.25),cex=1.75,
     adj = 1, labels = c(expression(paste(Delta,A^0)),expression(lambda^St),expression(lambda[i]^var),expression(lambda[f]^var)),xpd=TRUE)

segments(barCenters, tabbedMeans - tabbedSE * 2, barCenters,
         tabbedMeans + tabbedSE * 2, lwd = 1.5)

arrows(barCenters, tabbedMeans - tabbedSE * 2, barCenters,
       tabbedMeans + tabbedSE * 2, lwd = 1.5, angle = 90,
       code = 3, length = 0.05)

axis(2,at=seq(-1,5.0,0.5),pos=0,cex.axis=1.5,lwd=2,las=1)
title(cex.main=1.75,ylab="Free energy (eV)",cex.lab=1.75,line=3.5)


dev.off()
